/**
 * 2007, Digitalis Informatica. All rights reserved. Distribuicao e Gestao de
 * Informatica, Lda. Estrada de Paco de Arcos num.9 - Piso -1 2780-666 Paco de
 * Arcos Telefone: (351) 21 4408990 Fax: (351) 21 4408999
 * http://www.digitalis.pt
 */
package pt.digitalis.iss;

/**
 * Defines the ISS behaviour expected by clients.
 * 
 * @author Rodrigo Gonçalves <a
 *         href="mailto:rgoncalves@digitalis.pt">rgoncalves@digitalis.pt</a><br/>
 */
public interface ISS {

    /**
     * Delegates the process execution to the ISS. Clients call this method to
     * apply for a request service.
     * 
     * @param aProcess
     *            the process to execute
     * @param id
     *            an explicit id for the request
     * @return the service request associated to the process passed
     */
    public ServiceRequest delegate(IProcess aProcess, String id);

    /**
     * Overload of the <code>delegate()</code> method. The client uses this
     * variant if it does not wishes to pass an id of its own. 
     * 
     * @param process
     *            the process to execute
     * @return the service request associated to the process passed
     * 
     * @see pt.digitalis.iss.ISS#delegate(IProcess, String)
     */
    public ServiceRequest delegate(IProcess process);

    /**
     * This method informs if a request with a given id is already being served,
     * was served or is waiting.
     * 
     * Clients should use this method when the id is supplied externally to find
     * if a request is already in the system.
     * 
     * @param id
     *            the id of the request
     * @return T if the request is on the index, F otherwise
     */
    public boolean existsRequest(String id);

    /**
     * Returns the execution results to the client.
     * 
     * @param requestID
     *            the request id
     * @return the request execution results
     */
    public ServiceRequest fetchResults(String requestID);

    /**
     * Returns the estimated time of execution for a given process.
     * 
     * @param requestID
     *            the id of the process
     * 
     * @return the estimated time of execution for the given process in
     *         milliseconds
     */
    public long getEstimatedTimeOfExecution(String requestID);
    
    /**
     * Returns the value of the statistics logging control flag.
     * 
     * @return the statisticsDumpEnabled value
     */
    public boolean isStatisticsDumpEnabled() ;
    

    /**
     * Sets the value of the statistics logging control flag.
     * 
     * @param showStatistics
     *            the statisticsDumpEnabled new value
     */
    public void setStatisticsDumpEnabled(boolean showStatistics);
}
