/** 2007, Digitalis Informatica. All rights reserved.
 * 
 * Distribuicao e Gestao de Informatica, Lda.
 * Estrada de Paco de Arcos num.9 - Piso -1
 * 2780-666 Paco de Arcos
 * Telefone: (351) 21 4408990
 * Fax: (351) 21 4408999
 * http://www.digitalis.pt 
 */

package pt.digitalis.iss;

/**
 * This interface provides operations related to request management between the
 * ISS and the Worker. Through this interface a Worker can fetch request from
 * the ISS as well as return the results and notify the ISS that it has finished
 * it's work.
 * 
 * @author Rodrigo Gonçalves <a
 *         href="mailto:rgoncalves@digitalis.pt">rgoncalves@digitalis.pt</a><br/>
 * 
 */
public interface ISSRequestManagement {

    /**
     * Gets a request that is waiting for service.
     * 
     * @return a queued request
     */
    public ServiceRequest getWaitingRequest();

    /**
     * Callback method for the Workers to call when they finish.
     * 
     * @param returned
     *            the serviced request
     */
    public void returnRequest(ServiceRequest returned);

    /**
     * Tests if the current number of workers is above the current limit
     * 
     * @return true if there are more workers the allowed
     */
    public boolean areTooManyWorkers();
    
    /** Callback method to notify ISS of Worker's execution end. */
    public void notifyWorkerFinished();
}
