/** 2007, Digitalis Informatica. All rights reserved.
 * 
 * Distribuicao e Gestao de Informatica, Lda.
 * Estrada de Paco de Arcos num.9 - Piso -1
 * 2780-666 Paco de Arcos
 * Telefone: (351) 21 4408990
 * Fax: (351) 21 4408999
 * http://www.digitalis.pt 
 */

package pt.digitalis.iss;

import java.util.HashMap;
import java.util.Map;

/**
 * This class encapsulates the results of the process execution. It includes an
 * error flag as well as a collection of results. 
 * <br>
 * There are methods supplied to change and inspection of the error flag and the
 * results collection.
 * 
 * @author Rodrigo Gonçalves <a
 *         href="mailto:rgoncalves@digitalis.pt">rgoncalves@digitalis.pt</a><br/>
 */
public class ProcessResults {

	/** Error flag. */
	private boolean onError = false;

	/** Results map. */
	private Map<String, Object> theResults = new HashMap<String, Object>();

	/**
	 * Error flag inspector.
	 * 
	 * @return the onError state
	 */
	public boolean isOnError() {
		return this.onError;
	}

	/**
	 * Error flag modifier.
	 * 
	 * @param onError the error flag value to set
	 */
	public void setOnError(boolean onError) {
		this.onError = onError;
	}

	/**
	 * Results map inspector.
	 * 
	 * @return the results map
	 */
	public Map<String, Object> getResults() {
		return this.theResults;
	}

	/**
	 * Results map modifier.
	 * 
	 * @param newResults the theResults to set
	 */
	public void setResults(Map<String, Object> newResults) {
		this.theResults = newResults;
	}

	/**
	 * Fetches a result with a given id.
	 * 
	 * @param id the id of the result to fetch
	 * @return the value of the result with the given id, null if the supplied
	 *         id doesn't exist
	 */
	public Object getResult(String id) {
		return this.theResults.get(id);
	}

	/**
	 * Sets an individual result.
	 * 
	 * @param id the result id
	 * @param value the result value
	 */
	public void setResult(String id, Object value) {
		this.theResults.put(id, value);
	}
}
